<a name="v2"></a>

## v2(v, [y])
Create a 2D cartesian vector object `{x,y}`

**Kind**: global function  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> \| <code>number</code> | plain `{x,y}` vector or x-coordinate. |
| [y] | <code>number</code> | y-coordinate. |

**Example**  
```js
const u  = v2(3,4),       // create vector as ...
      u2 = v2({x:3,y:4}); // ... smart alternative ...
      u3 = {x:3,y:4};     // ... to simple object notation.
```

* [v2(v, [y])](#v2)
    * _instance_
        * [.isZero](#v2+isZero) : <code>boolean</code>
        * [.r](#v2+r) : <code>number</code>
        * [.w](#v2+w) : <code>number</code>
        * [.cpy](#v2+cpy) : <code>object</code>
        * [.sqr](#v2+sqr) : <code>number</code>
        * [.tilde](#v2+tilde) : <code>object</code>
        * [.neg](#v2+neg) : <code>object</code>
        * [.unit](#v2+unit) : <code>object</code>
        * [.inv](#v2+inv) : <code>object</code>
        * [.plain](#v2+plain) : <code>object</code>
        * [.set(v)](#v2+set) ⇒ <code>object</code>
        * [.freeze()](#v2+freeze) ⇒ <code>object</code>
        * [.equals(v2)](#v2+equals) ⇒ <code>boolean</code>
        * [.dot(v)](#v2+dot) ⇒ <code>number</code>
        * [.symp(v)](#v2+symp) ⇒ <code>number</code>
        * [.add(v)](#v2+add) ⇒ <code>object</code>
        * [.sub(v)](#v2+sub) ⇒ <code>object</code>
        * [.scl([s])](#v2+scl) ⇒ <code>object</code>
        * [.rot([w])](#v2+rot) ⇒ <code>object</code>
        * [.simtrf(lam, mu)](#v2+simtrf) ⇒ <code>object</code>
        * [.itilde()](#v2+itilde) ⇒ <code>object</code>
        * [.ineg()](#v2+ineg) ⇒ <code>object</code>
        * [.iunit()](#v2+iunit) ⇒ <code>object</code>
        * [.iinv()](#v2+iinv) ⇒ <code>object</code>
        * [.irot([w])](#v2+irot) ⇒ <code>object</code>
        * [.icpy(v)](#v2+icpy) ⇒ <code>object</code>
        * [.iscl([s])](#v2+iscl) ⇒ <code>object</code>
        * [.iadd(v)](#v2+iadd) ⇒ <code>object</code>
        * [.isub(v)](#v2+isub) ⇒ <code>object</code>
        * [.isimtrf([lam], [mu])](#v2+isimtrf) ⇒ <code>object</code>
        * [.cstrLen(v, [ratio])](#v2+cstrLen) ⇒ <code>object</code>
        * [.cstrAng(v, [w])](#v2+cstrAng) ⇒ <code>object</code>
        * [.toString()](#v2+toString) ⇒ <code>string</code>
    * _static_
        * [.zero](#v2.zero)
        * [.xunit](#v2.xunit)
        * [.yunit](#v2.yunit)
        * [.cpy(v)](#v2.cpy) ⇒ <code>object</code>
        * [.sqr(v)](#v2.sqr) ⇒ <code>object</code>
        * [.tilde(v)](#v2.tilde) ⇒ <code>object</code>
        * [.neg(v)](#v2.neg) ⇒ <code>object</code>
        * [.unit(v)](#v2.unit) ⇒ <code>object</code>
        * [.inv(v)](#v2.inv) ⇒ <code>object</code>
        * [.equals(a, b)](#v2.equals) ⇒ <code>boolean</code>
        * [.dot(a, b)](#v2.dot) ⇒ <code>number</code>
        * [.symp(a, b)](#v2.symp) ⇒ <code>number</code>
        * [.sum(a, b)](#v2.sum) ⇒ <code>object</code>
        * [.dif(a, b)](#v2.dif) ⇒ <code>object</code>
        * [.scl(v, s)](#v2.scl) ⇒ <code>object</code>
        * [.rot(v, w)](#v2.rot) ⇒ <code>object</code>
        * [.ref(v)](#v2.ref) ⇒ <code>object</code>
        * [.case1()](#v2.case1) ⇒ <code>string</code>
        * [.case2()](#v2.case2) ⇒ <code>string</code>
        * [.case3()](#v2.case3) ⇒ <code>string</code>
        * [.case4()](#v2.case4) ⇒ <code>string</code>
        * [.case5()](#v2.case5) ⇒ <code>string</code>

<a name="v2+isZero"></a>

### v2.isZero : <code>boolean</code>
Test for zero vector.<br>

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4), u2 = {x:-3,y:-4};
u.add(u2).isZero;   // true
u.sub(u2).isZero;   // false
```
<a name="v2+r"></a>

### v2.r : <code>number</code>
Magnitude / length

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.r === 5;   // true
```
<a name="v2+w"></a>

### v2.w : <code>number</code>
angle in [rad]

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,3);
u.w === Math.PI/4;   // true
```
<a name="v2+cpy"></a>

### v2.cpy : <code>object</code>
Provide copy of this vector.

**Kind**: instance property of [<code>v2</code>](#v2)  
<a name="v2+sqr"></a>

### v2.sqr : <code>number</code>
Provide magnitude squared.

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.sqr === 25;   // true
```
<a name="v2+tilde"></a>

### v2.tilde : <code>object</code>
provide tilde (orthogonal) vector

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.dot(u.tilde) === 0;   // true
```
<a name="v2+neg"></a>

### v2.neg : <code>object</code>
negated vector

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.neg.plain;   // {x:-3,y:-4}
```
<a name="v2+unit"></a>

### v2.unit : <code>object</code>
getting unit (normalized direction) vector.
setting unit changes direction and preserves magnitude.

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.unit;             // { x: 0.6, y: 0.8 }
u.unit = {x:0,y:1}  // { x: 0, y: 5 }
```
<a name="v2+inv"></a>

### v2.inv : <code>object</code>
inverted vector
i.e. `u.dot(u.inv) === 1`

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.dot(u.inv) === 1;   // true
```
<a name="v2+plain"></a>

### v2.plain : <code>object</code>
provide plain (prototype-free) vector

**Kind**: instance property of [<code>v2</code>](#v2)  
**Example**  
```js
const u = v2(3,4);
u.plain;   // {x:3,y:4}
```
<a name="v2+set"></a>

### v2.set(v) ⇒ <code>object</code>
Set coordinates from another vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | source vector. |

**Example**  
```js
let u1 = v2(3,4);
u1.set({x:1,y:2}).plain;   // {x:1,y:2}
```
<a name="v2+freeze"></a>

### v2.freeze() ⇒ <code>object</code>
Turn into immutable object

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  
**Example**  
```js
let u = v2(3,4);
u.freeze().set({x:1,y:2});   // error
```
<a name="v2+equals"></a>

### v2.equals(v2) ⇒ <code>boolean</code>
vector comparison

**Kind**: instance method of [<code>v2</code>](#v2)  

| Param | Type | Description |
| --- | --- | --- |
| v2 | <code>object</code> | other vector. |

**Example**  
```js
const u = v2(3,4);
u.equals(u.plain);    // true
```
<a name="v2+dot"></a>

### v2.dot(v) ⇒ <code>number</code>
dot (inner) product

**Kind**: instance method of [<code>v2</code>](#v2)  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

**Example**  
```js
const u1 = v2(3,4), u2 = v2(1,2);
u1.dot(u2) === 11;   // true
```
<a name="v2+symp"></a>

### v2.symp(v) ⇒ <code>number</code>
symplectic (inner) product
or use alias `perp(v)`

**Kind**: instance method of [<code>v2</code>](#v2)  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

**Example**  
```js
const u = v2(3,4), u2 = v2(1,2);
u.symp(u2) === 2;        // true ... same as
u.tilde.dot(u2) === 2;   // true
```
<a name="v2+add"></a>

### v2.add(v) ⇒ <code>object</code>
vector addition

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

**Example**  
```js
const u = v2(3,4);
u.add({x:2,y:1});    // {x:5,y:5}
```
<a name="v2+sub"></a>

### v2.sub(v) ⇒ <code>object</code>
vector subtraction

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

**Example**  
```js
const u = v2(3,4);
u.sub({x:2,y:1});    // {x:1,y:3}
```
<a name="v2+scl"></a>

### v2.scl([s]) ⇒ <code>object</code>
vector scaling

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [s] | <code>number</code> | <code>1</code> | scale factor. |

**Example**  
```js
const u = v2(3,4);
u.scl(2);    // {x:6,y:8}
```
<a name="v2+rot"></a>

### v2.rot([w]) ⇒ <code>object</code>
vector rotation

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [w] | <code>number</code> | <code>0</code> | rotation  angle [rad]. |

**Example**  
```js
let u = v2(3,4);
u.rot(Math.PI/2);    // {x:-4,y:3}
```
<a name="v2+simtrf"></a>

### v2.simtrf(lam, mu) ⇒ <code>object</code>
vector similarity transform

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| lam | <code>number</code> | first transform factor. |
| mu | <code>number</code> | second transform factor. |

**Example**  
```js
const u = v2(3,4);
u.simtrf(1,2);                 // same as ...
u.scl(1).add(u.tilde.scl(2))   // ...
```
<a name="v2+itilde"></a>

### v2.itilde() ⇒ <code>object</code>
inplace tilde (orthogonalized) vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  
<a name="v2+ineg"></a>

### v2.ineg() ⇒ <code>object</code>
inplace negate vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  
<a name="v2+iunit"></a>

### v2.iunit() ⇒ <code>object</code>
inplace normalize (to unit) vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  
<a name="v2+iinv"></a>

### v2.iinv() ⇒ <code>object</code>
inplace invert vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  
<a name="v2+irot"></a>

### v2.irot([w]) ⇒ <code>object</code>
inplace rotate vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [w] | <code>number</code> | <code>0</code> | rotation angle [rad]. |

<a name="v2+icpy"></a>

### v2.icpy(v) ⇒ <code>object</code>
inplace copy another vector (prefer v2.set here for short !)

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | source vector. |

<a name="v2+iscl"></a>

### v2.iscl([s]) ⇒ <code>object</code>
inplace scale vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [s] | <code>number</code> | <code>1</code> | scale factor. |

<a name="v2+iadd"></a>

### v2.iadd(v) ⇒ <code>object</code>
inplace add vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

<a name="v2+isub"></a>

### v2.isub(v) ⇒ <code>object</code>
inplace subtract vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | other vector. |

<a name="v2+isimtrf"></a>

### v2.isimtrf([lam], [mu]) ⇒ <code>object</code>
inplace similarity transform vector

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [lam] | <code>number</code> | <code>1</code> | first transform factor. |
| [mu] | <code>number</code> | <code>0</code> | second transform factor. |

<a name="v2+cstrLen"></a>

### v2.cstrLen(v, [ratio]) ⇒ <code>object</code>
Keep length / magnitude ratio to vector `v` constant.

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| v | <code>object</code> |  | other vector. |
| [ratio] | <code>number</code> | <code>1</code> | magnitude ratio . |

<a name="v2+cstrAng"></a>

### v2.cstrAng(v, [w]) ⇒ <code>object</code>
Keep absolute angle to vector `v` constant.

**Kind**: instance method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - this  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| v | <code>object</code> |  | other vector. |
| [w] | <code>number</code> | <code>0</code> | angle in radians. |

<a name="v2+toString"></a>

### v2.toString() ⇒ <code>string</code>
formatted output string of vector '{x,y,r,w}'.

**Kind**: instance method of [<code>v2</code>](#v2)  
<a name="v2.zero"></a>

### v2.zero
constant zero v2 vector (freezed).

**Kind**: static property of [<code>v2</code>](#v2)  
<a name="v2.xunit"></a>

### v2.xunit
constant x-unit v2 vector (freezed).

**Kind**: static property of [<code>v2</code>](#v2)  
<a name="v2.yunit"></a>

### v2.yunit
constant y-unit v2 vector (freezed).

**Kind**: static property of [<code>v2</code>](#v2)  
<a name="v2.cpy"></a>

### v2.cpy(v) ⇒ <code>object</code>
Create copy of (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.sqr"></a>

### v2.sqr(v) ⇒ <code>object</code>
Get magnitude squared of (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.tilde"></a>

### v2.tilde(v) ⇒ <code>object</code>
Get orthogonal vector from (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.neg"></a>

### v2.neg(v) ⇒ <code>object</code>
Get negative vector from (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.unit"></a>

### v2.unit(v) ⇒ <code>object</code>
Get unit vector from (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.inv"></a>

### v2.inv(v) ⇒ <code>object</code>
Get inverse vector from (plain) vector `v`.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | plain vector. |

<a name="v2.equals"></a>

### v2.equals(a, b) ⇒ <code>boolean</code>
Test two (plain) vectors for equality.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>boolean</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| a | <code>object</code> | (plain) vector. |
| b | <code>object</code> | (plain) vector. |

<a name="v2.dot"></a>

### v2.dot(a, b) ⇒ <code>number</code>
Dot (inner) product of two (plain) vectors.

**Kind**: static method of [<code>v2</code>](#v2)  

| Param | Type | Description |
| --- | --- | --- |
| a | <code>object</code> | (plain) vector. |
| b | <code>object</code> | (plain) vector. |

<a name="v2.symp"></a>

### v2.symp(a, b) ⇒ <code>number</code>
Symplectic (inner) product of two (plain) vectors.

**Kind**: static method of [<code>v2</code>](#v2)  

| Param | Type | Description |
| --- | --- | --- |
| a | <code>object</code> | (plain) vector. |
| b | <code>object</code> | (plain) vector. |

<a name="v2.sum"></a>

### v2.sum(a, b) ⇒ <code>object</code>
Create sum of two (plain) vectors.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| a | <code>object</code> | (plain) vector. |
| b | <code>object</code> | (plain) vector. |

<a name="v2.dif"></a>

### v2.dif(a, b) ⇒ <code>object</code>
Create difference of two (plain) vectors.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| a | <code>object</code> | (plain) vector. |
| b | <code>object</code> | (plain) vector. |

<a name="v2.scl"></a>

### v2.scl(v, s) ⇒ <code>object</code>
Create scaled vector from (plain) vector.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | (plain) vector. |
| s | <code>number</code> | scaling factor. |

<a name="v2.rot"></a>

### v2.rot(v, w) ⇒ <code>object</code>
Create rotateded vector from (plain) vector.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | (plain) vector. |
| w | <code>number</code> | rotation angle [rad]. |

<a name="v2.ref"></a>

### v2.ref(v) ⇒ <code>object</code>
Create a vector with coordinates referencing coordinates of other vector.

**Kind**: static method of [<code>v2</code>](#v2)  
**Returns**: <code>object</code> - v2  

| Param | Type | Description |
| --- | --- | --- |
| v | <code>object</code> | (plain) vector. |

<a name="v2.case1"></a>

### v2.case1() ⇒ <code>string</code>
First case of the planar vector equation.
Vector `a` is modified.
s. https://www.researchgate.net/publication/330997539_The_Five_Cases_of_the_Planar_Vector_Equation

**Kind**: static method of [<code>v2</code>](#v2)  
<a name="v2.case2"></a>

### v2.case2() ⇒ <code>string</code>
Second case of the planar vector equation.
 * Magnitude of `a` and direction of `b` is modified.
s. https://www.researchgate.net/publication/330997539_The_Five_Cases_of_the_Planar_Vector_Equation

**Kind**: static method of [<code>v2</code>](#v2)  
<a name="v2.case3"></a>

### v2.case3() ⇒ <code>string</code>
Third case of the planar vector equation.
Magnitude of `a` and magnitude of `b` is modified.
s. https://www.researchgate.net/publication/330997539_The_Five_Cases_of_the_Planar_Vector_Equation

**Kind**: static method of [<code>v2</code>](#v2)  
<a name="v2.case4"></a>

### v2.case4() ⇒ <code>string</code>
Fourth case of the planar vector equation.
Direction of `a` and direction of `b` is modified.
s. https://www.researchgate.net/publication/330997539_The_Five_Cases_of_the_Planar_Vector_Equation

**Kind**: static method of [<code>v2</code>](#v2)  
<a name="v2.case5"></a>

### v2.case5() ⇒ <code>string</code>
Fifth case of the planar vector equation.
Direction of `a` and direction of `b` is modified.
s. https://www.researchgate.net/publication/330997539_The_Five_Cases_of_the_Planar_Vector_Equation

**Kind**: static method of [<code>v2</code>](#v2)  
